/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.lpkg.deployer.internal.wrapper.bundle;

import com.liferay.portal.kernel.util.StringBundler;

import java.net.URL;

import java.util.Dictionary;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.service.url.URLConstants;
import org.osgi.service.url.URLStreamHandlerService;
import org.osgi.util.tracker.ServiceTracker;

/**
 * @author Shuyang Zhou
 */
public class WARBundleWrapperBundleActivator implements BundleActivator {

	@Override
	public void start(final BundleContext bundleContext) throws Exception {
		Bundle bundle = bundleContext.getBundle();

		Dictionary<String, String> headers = bundle.getHeaders();

		String contextName = headers.get("Liferay-WAB-Context-Name");

		if (contextName == null) {
			throw new IllegalArgumentException(
				"The header \"Liferay-WAB-Context-Name\" is null");
		}

		String lpkgURLString = headers.get("Liferay-WAB-LPKG-URL");

		if (lpkgURLString == null) {
			throw new IllegalArgumentException(
				"The header \"Liferay-WAB-LPKG-URL\" is null");
		}

		String startLevelString = headers.get("Liferay-WAB-Start-Level");

		if (startLevelString == null) {
			throw new IllegalArgumentException(
				"The header \"Liferay-WAB-Start-Level\" is null");
		}

		int startLevel = Integer.parseInt(startLevelString);

		// Defer WAR bundle installation until WAB protocol handler is ready

		_serviceTracker = new ServiceTracker<>(
			bundleContext,
			bundleContext.createFilter(
				StringBundler.concat(
					"(&(", URLConstants.URL_HANDLER_PROTOCOL,
					"=webbundle)(objectClass=",
					URLStreamHandlerService.class.getName(), "))")),
			new URLStreamHandlerServiceServiceTrackerCustomizer(
				bundleContext, contextName, new URL(lpkgURLString),
				startLevel));

		_serviceTracker.open();
	}

	@Override
	public void stop(BundleContext bundleContext) {
		_serviceTracker.close();
	}

	private ServiceTracker<URLStreamHandlerService, Bundle> _serviceTracker;

}